import mygeotab
from collections import namedtuple

def from_credentials(credentials):
    creds = {
        'username': credentials['username'],
        'password': credentials['password'] if 'password' in credentials else None,
        'database': credentials['database'],
        'session_id': credentials['session_id'] if 'session_id' in credentials else None,
        'server': credentials['server'] if 'server' in credentials else 'my.geotab.com'
    }

    nt = namedtuple('credentials', creds.keys())(*creds.values())
    return mygeotab.API.from_credentials(nt)

def authenticate(username, password, database, server=None):
    client = mygeotab.API(username=username, password=password, database=database) if server == None else mygeotab.API(username=username, password=password, database=database, server=server)
    client.authenticate()
    return client


import asyncio
import mygeotab
import datetime

async def get_feed(client, typeName, resultLimit, fromDate=None, fromVersion=None):
    if(fromVersion != None):
        res = await client.call_async('GetFeed', typeName=typeName, resultsLimit=resultLimit, fromVersion=fromVersion, search={
                'fromDate': fromDate if fromDate != None else datetime.datetime.now().isoformat()
        })

        return res
    else:
        res = await client.call_async('GetFeed', typeName=typeName, resultsLimit=resultLimit, search={
            'fromDate': fromDate if fromDate != None else datetime.datetime.now().isoformat()
        })

        return res


import asyncio
import mygeotab
import datetime

async def get_data(client, typeName, resultLimit):
        res = await client.call_async('Get', typeName=typeName, resultsLimit=resultLimit)
        return res